{% extends "cosmicdb/base.html" %}

{% block title %}Reset Password{% endblock %}

{% load static crispy_forms_tags cosmic_tags %}

{% block body %}
<body class="hold-transition login-page">
    <div class="login-box">
        <div class="login-logo">
        <a href="{% url 'home' %}"><img alt="Brand" src="{% static 'cosmicdb/img/icon.png' %}" class="login-img"><b>{% get_site_title %}</b></a>
        </div>
        <div class="login-box-body">
            <p class="login-box-msg">Forgotten your password?</p>
            <p class="login-box-msg">Enter your email address below, and we'll email instructions for setting a new one.</p>
            {% crispy form %}
        </div>
    </div>
</body>
{% endblock %}