<!DOCTYPE html>
<html lang="en">
<head>

{% load static %}

<meta charset="utf-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no" name="viewport">
<title>{% block title %}{% endblock %}</title>

<link rel="stylesheet" href="{% static 'cosmicdb/adminlte/bootstrap/css/bootstrap.min.css'%}">
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.5.0/css/font-awesome.min.css">
<link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/ionicons/2.0.1/css/ionicons.min.css">
<link rel="stylesheet" href="{% static 'cosmicdb/adminlte/dist/css/AdminLTE.min.css'%}">
<link rel="stylesheet" href="{% static 'cosmicdb/adminlte/dist/css/skins/skin-blue-light.min.css'%}">

<style>
    {% block style %}
    {% endblock %}
    {% block extrastyle %}
    {% endblock %}
</style>


{% block extrahead %}
{% endblock %}

</head>

{% block body %}
<body class="hold-transition skin-blue-light sidebar-mini">
</body>
{% endblock %}

</html>