{% extends 'cosmicdb/base_site.html' %}

{% block title %}Notification{% endblock %}
{% block title_small %}{% endblock %}

{% block style %}
    {{ block.super }}
    .notification-created-at {
        font-size: 80%;
    }
{% endblock %}

{% block breadcrumb %}
    <ol class="breadcrumb">
        <li><a href="{% url 'dashboard' %}"><i class="fa fa-dashboard"></i> Dashboard</a></li>
        <li><a href="{% url 'notifications' %}">Notifications</a></li>
        <li class="active">Notification</li>
    </ol>
{% endblock %}

{% block content %}
    <div class="box box-primary">
        <div class="box-header with-border">
            <h3 class="box-title"><i class="{{notification.icon_class}}"></i></h3>
            <p class="notification-created-at pull-right">{{notification.created_at}}</p>
        </div>
        <div class="box-body">
            {{notification.notification|safe|linebreaks}}
        </div>
    </div>
{% endblock %}