<!-- Optionally, you can add icons to the links -->
{% url 'dashboard' as dashboard_url %}
<li{% if request.path == dashboard_url %} class="active"{% endif %}><a href="{{dashboard_url}}"><i class="fa fa-dashboard"></i> <span>Dashboard</span></a></li>
