{% extends 'cosmicdb/base_site.html' %}

{% block title %}Messages{% endblock %}
{% block title_small %}{% endblock %}

{% block style %}
    {{ block.super }}
    .read_column {
        width: 60px;
    }
{% endblock %}

{% block javascript %}
    {{ block.super }}
    $(document).ready(function(){
    });
    function goTo(trElement){
        temp_url = '{% url 'messages' 0 %}';
        var url = temp_url.substr(0,temp_url.length-2)+$(trElement).data('id')+'/';
        window.location.href = url;
    }
{% endblock %}

{% block breadcrumb %}
    <ol class="breadcrumb">
        <li><a href="{% url 'dashboard' %}"><i class="fa fa-dashboard"></i> Dashboard</a></li>
        <li class="active">Messages</li>
    </ol>
{% endblock %}

{% load render_table from django_tables2 %}

{% block content %}

    <div class="box box-primary">
        <div class="box-body">
            {% render_table table %}
        </div>
    </div>

{% endblock %}