{% extends 'cosmicdb/base.html' %}

{% load cosmic_tags %}

{%block fulltitle%}{% get_site_title %} | {% block title %}Sign Up{% endblock %}{% endblock %}

{% load crispy_forms_tags %}

{% block body %}
<body class="hold-transition skin-blue-light sidebar-mini">
    <div class="container">
        <div class="row">
            <div class="col-xs-12">
                <div class="page-header">
                    <h1>Sign Up</h1>
                </div>
                <div class="box box-primary">
                    <div class="box-header with-border">
                        <h3 class="box-title">Account Details</h3>
                    </div>

                    <div class="box-body">
                        {% crispy form %}
                    </div>

                </div>
            </div>
        </div>
    </div>
</body>
{% endblock %}