{% extends 'cosmicdb/base_site.html' %}

{% block title %}Change Password{% endblock %}
{% block title_small %}{% endblock %}

{% block breadcrumb %}
    <ol class="breadcrumb">
        <li><a href="{% url 'dashboard' %}"><i class="fa fa-dashboard"></i> Dashboard</a></li>
        <li class="active">Change Password</li>
    </ol>
{% endblock %}

{% load crispy_forms_tags %}

{% block content %}
    <div class="box box-primary">
        <div class="box-body">
            {% crispy form %}
        </div>
    </div>
{% endblock %}