{% extends "cosmicdb/base.html" %}


{% block title %}Login{% endblock %}

{% load static crispy_forms_tags cosmic_tags %}

{% block body %}

<body class="hold-transition login-page">

    <div class="login-box">
        <div class="login-logo">
        <a href="{% url 'home' %}"><img alt="Brand" src="{% static 'cosmicdb/img/icon.png' %}" class="login-img"><b>{% get_site_title %}</b></a>
        </div>
        <div class="login-box-body">
            <p class="login-box-msg"><strong>Sign in to start your session</strong></p>

            {% crispy form %}

            <div class="login-below-sign-in">
                <a href="{% url 'password_reset' %}">I forgot my password</a><br>
                {% get_signup_link_login %}
            </div>

        </div>

    </div>

</body>
{% endblock %}