{% extends "cosmicdb/base.html" %}

{% block title %}Completed Reset{% endblock %}

{% load static cosmic_tags %}

{% block body %}
    <body class="hold-transition login-page">
        <div class="login-box">
            <div class="login-logo">
            <a href="{% url 'home' %}"><img alt="Brand" src="{% static 'cosmicdb/img/icon.png' %}" class="login-img"><b>{% get_site_title %}</b></a>
            </div>
            <div class="login-box-body">
                <p class="login-box-msg">Your password has been set.</p>
                <p class="login-box-msg">You may go ahead and log in now.</p>
                <p class="login-box-msg"><a href="{% url 'login' %}">Log In</a></p>
            </div>
        </div>
    </body>
{% endblock %}