{% extends 'errors_base.html' %}

{% block title %}Page Error 500{% endblock %}

{% load static %}

{% block style %}
    {{ block.super }}
    .login-box {
        width: initial;
    }
    .login-box-body {
        height: 400px;
    }
{% endblock %}

{% block body %}

<body class="hold-transition login-page">

    <div class="login-box">
        <div class="login-box-body">
            <div class="error-page">
                <h2 class="headline text-red"> 500</h2>
                <div class="error-content">
                    <h3><i class="fa fa-warning text-red"></i> Oops! Something went wrong.</h3>
                    <p>
                        We will work on fixing that right away.
                    </p>
                    <p>
                        Back to <a href="{% url 'home' %}">home</a>.
                    </p>
                </div>
            </div>
        </div>

    </div>

</body>
{% endblock %}