{% extends 'cosmicdb/base_site.html' %}

{% block title %}Dashboard{% endblock %}
{% block title_small %}{% endblock %}

{% block breadcrumb %}
    <ol class="breadcrumb">
        <li class="active"><a href="{% url 'dashboard' %}"><i class="fa fa-dashboard"></i> Dashboard</a></li>
    </ol>
{% endblock %}

{% block style %}
    {{ block.super }}
{% endblock %}

{% block javascript %}
    {{ block.super }}
    $(document).ready(function(){
    });
{% endblock %}

{% block content %}

    <div class="box box-primary">
        <div class="box-header">
            <h3>Dashboard</h3>
        </div>
        <div class="box-body">
            Extend 'cosmicdb/dashboard.html' template, aswell as 'cosmicdb/sidebar.html' for the sidebar
        </div>
    </div>

{% endblock %}